@@ -2,15 +2,15 @@ package DBIx::QuickDB::Driver::MariaDB;
 use strict;
 use warnings;
 
-our $VERSION = '0.000035';
+our $VERSION = '0.000036';
 
 use IPC::Cmd qw/can_run/;
 use Capture::Tiny qw/capture/;
 
-use parent 'DBIx::QuickDB::Driver::MySQL::Base';
+use parent 'DBIx::QuickDB::Driver::MySQL';
 use DBIx::QuickDB::Util::HashBase;
 
-sub provider { 'mariadb' }
+sub provider { 'MariaDB' }
 
 sub verify_provider {
     my $class = shift;
@@ -23,45 +23,11 @@ sub verify_provider {
     return 0;
 }
 
-my $NOT_MARIADB;
-{
-    my %found;
+sub server_bin_list  { qw/mariadbd mysqld/ }
+sub client_bin_list  { qw/mariadb mysql/ }
+sub install_bin_list { qw/mariadb-install-db mysql_install_db/ }
 
-    my $viable = 0;
-    if (my $mysqld = can_run('mariadbd') || can_run('mysqld')) {
-        if (__PACKAGE__->verify_provider($mysqld)) {
-            $found{server_bin} = $mysqld;
-        }
-        else {
-            $NOT_MARIADB = 1;
-        }
-    }
-
-    if (my $mysql = can_run('mariadb') || can_run('mysql')) {
-        if (__PACKAGE__->verify_provider($mysql)) {
-            $found{client_bin} = $mysql;
-        }
-        else {
-            $NOT_MARIADB = 1;
-        }
-    }
-
-    if (my $install = can_run('mariadb-install-db') || can_run('mysql_install_db')) {
-        my ($stdout, $stderr) = capture { system($install) };
-        my $output = $stdout . "\n" .  $stderr;
-        unless ($output =~ m/is deprecated/) {
-            $found{install_bin} = $install if __PACKAGE__->verify_provider($install);
-        }
-    }
-
-    for my $key (qw/server_bin client_bin install_bin/) {
-        my $val = $found{$key};
-        no strict 'refs';
-        *$key = sub() { $val };
-    }
-}
-
-sub dbd_driver_order { grep { $_ } $ENV{QDB_MARIADB_DBD}, $ENV{QDB_MYSQLD_DBD}, 'DBD::MariaDB', 'DBD::mysql' }
+sub dbd_driver_order { my $class = shift; $class->SUPER::dbd_driver_order($ENV{QDB_MARIADB_DBD}, $ENV{QDB_MYSQLD_DBD}) }
 
 sub list_env_vars {
     my $self = shift;
@@ -101,11 +67,11 @@ sub viable {
 
     my @bad;
 
-    push @bad => "Could not load either 'DBD::mysql' or 'DBD::MariaDB', needed for everything"
+    push @bad => "Could not load either 'DBD::MariaDB' or 'DBD::mysql', needed for everything"
         unless $this->dbd_driver;
 
-    if ($NOT_MARIADB) {
-        push @bad => "Installed MySQL is not MariaDB";
+    if (!keys %{$this->provider_info}) {
+        push @bad => "Installed MySQL is not " . $this->provider;
     }
     else {
         if ($spec->{bootstrap}) {
